OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
    "Authentication" : "Autentifikatsiya",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "Files" : "Fayllar",
    "View profile" : "View profile",
    "last month" : "last month",
    "seconds ago" : "seconds ago",
    "Apps" : "Apps",
    "Settings" : "Sozlamalar",
    "Accounts" : "Akkaunt",
    "Email" : "Email",
    "Website" : "Veb-sayt",
    "Address" : "Address",
    "Profile picture" : "Profil rasmi",
    "About" : "About",
    "Additional settings" : "Parol",
    "Set an admin password." : "Set an admin password.",
    "Open %s" : "Ochiq %s",
    "Sunday" : "Yakshanba",
    "Monday" : "Dushanba",
    "Tuesday" : "Seshanba",
    "Wednesday" : "Chorshanba",
    "Thursday" : "Payshanba",
    "Friday" : "Juma",
    "Saturday" : "Shanba",
    "January" : "January",
    "Authentication error" : "Authentication error",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "\"%2$s\" Jamg'armaning bulut provayderi tomonidan allaqachon \"%1$s\" identifikatori ishlatilgan",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" identifikatoriga ega Jamg'armaning bulut provayderi mavjud emas.",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Images" : "Tasvirlar",
    "Generated response" : "Yaratilgan javob",
    "Confirmation" : "Tasdiqlash",
    "Prompt" : "Tezkor",
    "Text" : "Matn",
    "Translate" : "Tarjima"
},
"nplurals=1; plural=0;");
